@@ -1,7 +1,5 @@
 package SQL::Translator::Parser::DBI::PostgreSQL;
 
-# -------------------------------------------------------------------
-# $Id: PostgreSQL.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -39,7 +37,8 @@ use DBI;
 use Data::Dumper;
 use SQL::Translator::Schema::Constants;
 
-use vars qw[ $DEBUG @EXPORT_OK ];
+use vars qw[ $DEBUG $VERSION @EXPORT_OK ];
+$VERSION = '1.59';
 $DEBUG   = 0 unless defined $DEBUG;
 
 # -------------------------------------------------------------------
