@@ -1,7 +1,5 @@
 package SQL::Translator::Parser::Excel;
 
-# -------------------------------------------------------------------
-# $Id: Excel.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -49,8 +47,9 @@ and field sizes.  True by default.
 =cut
 
 use strict;
-use vars qw($DEBUG @EXPORT_OK);
+use vars qw($DEBUG $VERSION @EXPORT_OK);
 $DEBUG = 0 unless defined $DEBUG;
+$VERSION = '1.59';
 
 use Spreadsheet::ParseExcel;
 use Exporter;
